package cn.com.infosec.x509;

import cn.com.infosec.i18n.ErrorBundle;
import cn.com.infosec.i18n.LocalizedException;
import java.security.cert.CertPath;

public class CertPathReviewerException extends LocalizedException {
   private int index = -1;
   private CertPath certPath = null;

   public CertPathReviewerException(ErrorBundle errorMessage, Throwable throwable) {
      super(errorMessage, throwable);
   }

   public CertPathReviewerException(ErrorBundle errorMessage) {
      super(errorMessage);
   }

   public CertPathReviewerException(ErrorBundle errorMessage, Throwable throwable, CertPath certPath, int index) {
      super(errorMessage, throwable);
      if (certPath != null && index != -1) {
         if (index >= -1 && index < certPath.getCertificates().size()) {
            this.certPath = certPath;
            this.index = index;
         } else {
            throw new IndexOutOfBoundsException();
         }
      } else {
         throw new IllegalArgumentException();
      }
   }

   public CertPathReviewerException(ErrorBundle errorMessage, CertPath certPath, int index) {
      super(errorMessage);
      if (certPath != null && index != -1) {
         if (index >= -1 && index < certPath.getCertificates().size()) {
            this.certPath = certPath;
            this.index = index;
         } else {
            throw new IndexOutOfBoundsException();
         }
      } else {
         throw new IllegalArgumentException();
      }
   }

   public CertPath getCertPath() {
      return this.certPath;
   }

   public int getIndex() {
      return this.index;
   }
}
